#!/usr/bin/env python

# It Creates a denim texture and and embroidery text
# author: Pocholo
# date: 5/8/2020

# Comments directed to http://gimpchat.com

# Installation:
# This script should be placed in the user plugins folder



# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY# without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>. 


from gimpfu import *

def pm_jean_texture_embroidery_text(img, draw, customtext, font, textcolor, fgColor):
	
	#Set Undo Start
	pdb.gimp_image_undo_group_start(img)
	
	#Initiates the temporary state
	pdb.gimp_context_push()
		
	#Variables
	Width = img.width
	Height = img.height
	
	#Remove initial layer image
	pdb.gimp_image_remove_layer(img, draw)
	
	#Create the text
	pdb.gimp_context_set_foreground(textcolor)
	layer = pdb.gimp_text_fontname(img, None, 100, 100, customtext, 40, 
												TRUE, 300, PIXELS, font)
	pdb.gimp_text_layer_set_justification(layer, 2)
	
	#Resize the text to the layer
	img.resize(layer.width, layer.height, 0, 0)
	
	
	#Create a blue background for the denim
	jeanlayer = pdb.gimp_layer_new(img, img.width, img.height, RGB, "Jean", 100, LAYER_MODE_NORMAL)
	pdb.gimp_image_add_layer(img, jeanlayer, 1)
	pdb.gimp_context_set_foreground(fgColor)
	pdb.gimp_drawable_fill(jeanlayer, FILL_FOREGROUND)
	pdb.plug_in_hsv_noise(img, jeanlayer, 1, 3, 4, 255)
	
	#Create the denim pattern
	non_empty = pdb.gimp_edit_copy(jeanlayer)
	patternLayer = pdb.gimp_layer_new(img, img.width, img.height, RGB, "Pattern", 100, LAYER_MODE_GRAIN_MERGE)
	pdb.gimp_image_add_layer(img, patternLayer, 1)
	pdb.gimp_layer_add_alpha(patternLayer)
	pdb.gimp_drawable_fill(patternLayer, FILL_TRANSPARENT)
	floating_sel = pdb.gimp_edit_paste(patternLayer, FALSE)
	pdb.gimp_floating_sel_anchor(floating_sel)
		
	#Create the texture
	pdb.plug_in_sinus(img, patternLayer, 1500, 900, 1.0, 0, TRUE, TRUE, 2, (202, 202, 202), (0, 0, 100), 1.0, 1.0, 2, -0.500)
	
	non_empty = pdb.gimp_edit_copy(layer)
	pdb.gimp_image_remove_layer(img, layer)
	copyLayer = pdb.gimp_layer_new(img, img.width, img.height, RGB, "Text copy1", 100, LAYER_MODE_NORMAL)
	pdb.gimp_image_add_layer(img, copyLayer, -3)
	pdb.gimp_layer_add_alpha(copyLayer)
	pdb.gimp_drawable_fill(copyLayer, FILL_TRANSPARENT)
	floating_sel = pdb.gimp_edit_paste(copyLayer, FALSE)
	pdb.gimp_floating_sel_anchor(floating_sel)
	
	#Apply layerfx to the first text
	#Bevel and Emboss	
	pdb.python_layerfx_bevel_emboss(img, copyLayer, 
									         1,   #style inner bevel
								            65,   #depth 
								             0,   #direction 
								            12,   #size 
									         5,   #soften
								           120,   #angle 
								            20,   #altitude 
									         9,   #gloss_contour 
							           "White",   #highlight_color 
								             4,   #highlight_mode-screen
								           100,   #highlight_opacity
							           "Black",   #shadow_color 
								            17,   #shadow_mode-burn
								            20,   #shadow_opacity 
								             0,   #surface_contour 
								         FALSE,   #use_texture 
							       "Dried mud",   #pattern 
								           100,   #scale 
								           100,   #tex_depth 
								          TRUE,   #invert 
								         FALSE)   #merge	
	
	#Stroke	
	pdb.python_layer_fx_stroke(img, copyLayer, 
							(160, 160, 0),	#color
									   40,	#opacity 
									   42,	#mode-dodge
										3,	#size 
									  100,  #position 
									FALSE)	#merge
	
	#Create a copy of the text	
	non_empty = pdb.gimp_edit_copy(copyLayer)
	copyLayer2 = pdb.gimp_layer_new(img, img.width, img.height, RGB, "Text copy2", 100, LAYER_MODE_GRAIN_MERGE)
	pdb.gimp_image_add_layer(img, copyLayer2, 0)
	pdb.gimp_layer_add_alpha(copyLayer2)
	pdb.gimp_drawable_fill(copyLayer2, FILL_TRANSPARENT)
	floating_sel = pdb.gimp_edit_paste(copyLayer2, FALSE)
	pdb.gimp_floating_sel_anchor(floating_sel)
			
	#Create a selection on the text
	pdb.gimp_image_select_item(img, 2, copyLayer)
	
	#Apply sinus filter for embroidery effect
	pdb.plug_in_sinus(img, copyLayer2, 1500, 1000, 1.0, 0, TRUE, TRUE, 2, (0, 0, 100), (textcolor), 1.0, 1.0, 2, -0.500)
	
	#Apply layerfx to the second text
	#Inner Glow								   
	pdb.python_layerfx_inner_glow(img, copyLayer2, 
							       (0, 0, 0),   #color
									      60,   #opacity
										   0,   #contou
										   0,   #noise
						 LAYER_MODE_MULTIPLY,   #mode 
										   1,   #source
										   0,   #choke 
									       7,   #size 
									   FALSE)   #merge
									   
	#Bevel and Emboss	
	pdb.python_layerfx_bevel_emboss(img, copyLayer2, 
									         3,   #style inner bevel
								            65,   #depth 
								             0,   #direction 
								            20,   #size 
									         3,   #soften
								           120,   #angle 
								            34,   #altitude 
									         0,   #gloss_contour 
							   (255, 255, 255),   #highlight_color 
								             4,   #highlight_mode-screen
								           100,   #highlight_opacity
							         (0, 0, 0),   #shadow_color 
								             3,   #shadow_mode-multiply
								            30,   #shadow_opacity 
								             0,   #surface_contour 
								         FALSE,   #use_texture 
							       "Dried mud",   #pattern 
								           100,   #scale 
								           100,   #tex_depth 
								          TRUE,   #invert 
										 FALSE)   #merge	
		
	#get rid of the selection
	pdb.gimp_selection_none(img)
	
	#Set Undo End
	pdb.gimp_image_undo_group_end(img)
	
	#Resets the previous user defaults
	pdb.gimp_context_pop()

register(
	"pm_jean_texture_embroidery_text",
	"Creates a denim texture and ebroidery text",
	"Creates a denim texture and ebroidery text",
	"Pocholo",
	"Pocholo",
	"2020",
	"Jean embroidery text",
	"RGB*",
[
	(PF_IMAGE, "img", "Input image", None),
	(PF_DRAWABLE, "draw", "Input drawable", None),
	(PF_STRING, "customtext", "Text string", 'Gimp Embroidery Text'),
    (PF_FONT, "font", "Font face", "Mardian Demo"),
	(PF_COLOR, "textcolor", "Text color", (245, 195, 40)),
	(PF_COLOR, "fgcolor", "Texture color", (0, 90, 170)),
],
[],
pm_jean_texture_embroidery_text, menu="<Image>/Pocholo-scripts/Jean embroidery text"),

main()	